#include <WiFi.h>
#include <Adafruit_AHTX0.h>
#include <HTTPClient.h>

// Replace with your network credentials
const char* ssid = "your_SSID";
const char* password = "your_PASSWORD";

// Replace with your ThingSpeak channel information
const char* server = "api.thingspeak.com";
const String api_key = "your_API_KEY";

Adafruit_AHTX0 aht;
Adafruit_Sensor *aht_humidity, *aht_temp;

void setup() {
  Serial.begin(115200);
  delay(1000);

  // Connect to WiFi network
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.println("Connecting to WiFi...");
  }

  Serial.println("Connected to WiFi");

  // Initialize AHT sensor
  if (!aht.begin()) {
    Serial.println("Failed to find AHT10/AHT20 chip");
    while (1) {
      delay(10);
    }
  }

  Serial.println("AHT10/AHT20 Found!");
  aht_temp = aht.getTemperatureSensor();
  aht_temp->printSensorDetails();

  aht_humidity = aht.getHumiditySensor();
  aht_humidity->printSensorDetails();
}

void loop() {
  // Get sensor readings
  sensors_event_t humidity;
  sensors_event_t temp;
  aht_humidity->getEvent(&humidity);
  aht_temp->getEvent(&temp);

  // Send data to ThingSpeak
  String url = "/update?";
  url += "api_key=" + api_key;
  url += "&field1=" + String(temp.temperature);
  url += "&field2=" + String(humidity.relative_humidity);

  HTTPClient http;
  http.begin(server, 80, url);
  int http_code = http.GET();
  http.end();

  // Wait 15 seconds before sending the next data to ThingSpeak
  delay(15000);
}
